@@ -395,7 +395,7 @@ class dyagram:
 
         try:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering EIGRP Neighbors - START")
-            time.sleep(5)  # FIXME: IF I DON'T PUT THIS HERE THERE IS AN EXCEPTION THROWN THAT I CAN'T CATCH
+            #time.sleep(5)  # FIXME: IF I DON'T PUT THIS HERE THERE IS AN EXCEPTION THROWN THAT I CAN'T CATCH
             discovered = self.discover_eigrp_neighbors_restconf()
 
             if not discovered:
@@ -443,8 +443,11 @@ class dyagram:
             dev.enable()
 
 
-            if os in ['cisco_ios', 'cisco_nxos', 'cisco_xr']:
+            if os in ['cisco_ios', 'cisco_nxos']:
                 eigrp_output = dev.send_command("show ip eigrp neighbors vrf all") #textfsm not currently supported for this command
+            elif os in ['cisco_xr']:
+                eigrp_output = dev.send_command(
+                    "show eigrp neighbors")  # textfsm not currently supported for this command
                 if isinstance(eigrp_output, str):
                     neighbor_ips = re.findall('\d+\.\d+\.\d+\.\d+', eigrp_output)
                     self.log.info(f"{device}: EIGRP NEIGHBOR IPs - {neighbor_ips}")
